// java wrapper for vtkImageReader2Factory object
//

package vtk;
import vtk.*;

public class vtkImageReader2Factory extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void RegisterReader_2(vtkImageReader2 id0);
  public void RegisterReader(vtkImageReader2 id0)
    { RegisterReader_2(id0); }

  private native long CreateImageReader2_3(String id0);
  public vtkImageReader2 CreateImageReader2(String id0) {
    long temp = CreateImageReader2_3(id0);

    if (temp == 0) return null;
    return (vtkImageReader2)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetRegisteredReaders_4(vtkImageReader2Collection id0);
  public void GetRegisteredReaders(vtkImageReader2Collection id0)
    { GetRegisteredReaders_4(id0); }

  public vtkImageReader2Factory() { super(); }

  public vtkImageReader2Factory(long id) { super(id); }
  public native long   VTKInit();

}
